==> huaweicloudsdkrds-3.1.98-py2.py3-none-any.whl: huaweicloudsdkrds/v3/model/reduce_volume_request_body.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class ReduceVolumeRequestBody:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'reduce_volume': 'ReduceVolumeObject'
    }

    attribute_map = {
        'reduce_volume': 'reduce_volume'
    }

    def __init__(self, reduce_volume=None):
        """ReduceVolumeRequestBody

        The model defined in huaweicloud sdk

        :param reduce_volume: 
        :type reduce_volume: :class:`huaweicloudsdkrds.v3.ReduceVolumeObject`
        """
        
        

        self._reduce_volume = None
        self.discriminator = None

        self.reduce_volume = reduce_volume

    @property
    def reduce_volume(self):
        """Gets the reduce_volume of this ReduceVolumeRequestBody.

        :return: The reduce_volume of this ReduceVolumeRequestBody.
        :rtype: :class:`huaweicloudsdkrds.v3.ReduceVolumeObject`
        """
        return self._reduce_volume

    @reduce_volume.setter
    def reduce_volume(self, reduce_volume):
        """Sets the reduce_volume of this ReduceVolumeRequestBody.

        :param reduce_volume: The reduce_volume of this ReduceVolumeRequestBody.
        :type reduce_volume: :class:`huaweicloudsdkrds.v3.ReduceVolumeObject`
        """
        self._reduce_volume = reduce_volume

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ReduceVolumeRequestBody):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkrds-3.1.157-py2.py3-none-any.whl: huaweicloudsdkrds/v3/model/reduce_volume_request_body.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class ReduceVolumeRequestBody:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'reduce_volume': 'ReduceVolumeObject'
    }

    attribute_map = {
        'reduce_volume': 'reduce_volume'
    }

    def __init__(self, reduce_volume=None):
        r"""ReduceVolumeRequestBody

        The model defined in huaweicloud sdk

        :param reduce_volume: 
        :type reduce_volume: :class:`huaweicloudsdkrds.v3.ReduceVolumeObject`
        """
        
        

        self._reduce_volume = None
        self.discriminator = None

        self.reduce_volume = reduce_volume

    @property
    def reduce_volume(self):
        r"""Gets the reduce_volume of this ReduceVolumeRequestBody.

        :return: The reduce_volume of this ReduceVolumeRequestBody.
        :rtype: :class:`huaweicloudsdkrds.v3.ReduceVolumeObject`
        """
        return self._reduce_volume

    @reduce_volume.setter
    def reduce_volume(self, reduce_volume):
        r"""Sets the reduce_volume of this ReduceVolumeRequestBody.

        :param reduce_volume: The reduce_volume of this ReduceVolumeRequestBody.
        :type reduce_volume: :class:`huaweicloudsdkrds.v3.ReduceVolumeObject`
        """
        self._reduce_volume = reduce_volume

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ReduceVolumeRequestBody):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
